sample_test_fail_all_setup_20150111_225227

### sample_config1

Total tests | Passed | Failed | Skipped | Start time | End time | Execution time | Naarad
--- | --- | --- | --- | --- | --- | --- | ---
3 | 0 | 0 | 3 | 2015-01-11 22:53:20 | 2015-01-11 22:53:20 | 0.247625827789 sec | Report

###

Test Name | Result | Description
--- | --- | ---
test1 | Skipped | Test has no docstring :(
test0 | Skipped | Test has no docstring :(
test2 | Skipped | Test has no docstring :(

###

Config Key | Value
--- | ---
TEST_OPTION | foo
BAR | baz
max_failures_per_suite_before_abort | 0